@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertBlock;
 
-our $DATE = '2015-06-18'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-07-02'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,6 +17,8 @@ with (
 
 use namespace::autoclean;
 
+has _directive_re => (is=>'rw', default=>sub{qr/INSERT_BLOCK/});
+
 sub munge_files {
     my $self = shift;
 
@@ -26,7 +28,8 @@ sub munge_files {
 sub munge_file {
     my ($self, $file) = @_;
     my $content = $file->content;
-    if ($content =~ s{^#\s*INSERT_BLOCK:\s*(.*)\s+(\w+)\s*$}{$self->_insert_block($1, $2, $file->name)."\n"}egm) {
+    my $directive = $self->_directive_re;
+    if ($content =~ s{^#\s*$directive:\s*(.*)\s+(\w+)\s*$}{$self->_insert_block($1, $2, $file->name)."\n"}egm) {
         $file->content($content);
     }
 }
@@ -78,7 +81,7 @@ Dist::Zilla::Plugin::InsertBlock - Insert a block of text from another file
 
 =head1 VERSION
 
-This document describes version 0.05 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-06-18.
+This document describes version 0.06 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2015-07-02.
 
 =head1 SYNOPSIS
 
